==> igniteui-react-charts-16.4.1.tgz: package/ES2015/LineSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { HorizontalAnchoredCategorySeries } from "./HorizontalAnchoredCategorySeries";
import { IUnknownValuePlotting_$type } from "igniteui-react-core/ES2015/IUnknownValuePlotting";
import { CategoryLineRasterizer } from "./CategoryLineRasterizer";
import { UnknownValuePlotting_$type } from "igniteui-react-core/ES2015/UnknownValuePlotting";
import { DependencyProperty } from "igniteui-react-core/ES2015/DependencyProperty";
import { Type, typeCast, runOn, enumGetBox, markType } from "igniteui-react-core/ES2015/type";
import { Path } from "igniteui-react-core/ES2015/Path";
import { ScalerParams } from "./ScalerParams";
import { PropertyMetadata } from "igniteui-react-core/ES2015/PropertyMetadata";
import { AnchoredCategorySeriesView } from "./AnchoredCategorySeriesView";
import { ISortingAxis_$type } from "./ISortingAxis";
import { Color } from "igniteui-react-core/ES2015/Color";
export class LineSeries extends HorizontalAnchoredCategorySeries {
    constructor() {
        super();
        this.p7 = null;
        this.p7 = new CategoryLineRasterizer();
        this.ab = LineSeries.$;
        this.pr = 0;
    }
    bf() {
        return new LineSeriesView(this);
    }
    il(a) {
        super.il(a);
        this.p8 = a;
    }
    get_ck() {
        return true;
    }
    get ck() {
        return this.get_ck();
    }
    preferredCategoryMode(a) {
        return this.pr;
    }
    ho(a, b) {
        super.ho(a, b);
        let c = b;
        c.c5();
    }
    oe(a, b) {
        super.oe(a, b);
        let c = b.cl.d;
        let d = typeCast(LineSeriesView.$, b);
        let e = a.f;
        let f = this.getEffectiveViewport1(b);
        this.m5.x(this, this.nq(), this.po, runOn(this, this.mr), this.ny(b), this.nz(b));
        let g = false;
        let h = this.m5.c;
        if (h != null) {
            g = true;
        }
        if (g) {
            let i = new ScalerParams(0, b.bq, b.bp, this.po.b8, f);
            this.oa(e, -1, this.valueColumn.count, this.po, i, b.n);
        }
        let j = d.db;
        let k = d.dc;
        let l = d.da;
        this.m5.ae(j, true, false, true, false);
        this.m5.ae(k, true, false, true, false);
        this.m5.ae(l, false, true, false, false);
        l._opacity = 0.75 * this.m5.i;
        if (b.cp(a)) {
            d.c6(e.count, e, true, this.unknownValuePlotting, this.om(e, e.count - 1, b.bp, b.bq), c, this.eq);
            b.cs(a);
        }
    }
    ir(a, b, c, d) {
        super.ir(a, b, c, d);
        switch (b) {
            case LineSeries.$$p[0]:
                this.m2.m = this.unknownValuePlotting == 0;
                this.i4(false);
                this.ib();
                break;
        }
    }
    get useHighMarkerFidelity() {
        return this.nt;
    }
}
LineSeries.$t = markType(LineSeries, 'LineSeries', HorizontalAnchoredCategorySeries.$, [IUnknownValuePlotting_$type]);
Type.dep(DependencyProperty, PropertyMetadata, LineSeries, 'raisePropertyChanged', ['UnknownValuePlotting::qa', [UnknownValuePlotting_$type, enumGetBox(UnknownValuePlotting_$type, 1)]]);
export class LineSeriesView extends AnchoredCategorySeriesView {
    constructor(a) {
        super(a);
        this.c4 = null;
        this.de = new Path();
        this.dd = new Path();
        this.df = new Path();
        this.c9 = new Path();
        this.c8 = new Path();
        this.c7 = new Path();
        this.c4 = a;
    }
    get db() {
        return this.de;
    }
    get dc() {
        return this.df;
    }
    get da() {
        return this.dd;
    }
    c5() {
        this.dd.aj = null;
        this.de.aj = null;
        this.df.aj = null;
        this.an();
    }
    c6(a, b, c, d, e, f, g) {
        this.c4.p7.a = typeCast(ISortingAxis_$type, this.cn.fetchXAxis()) !== null ? true : false;
        this.c4.p7.m(this.de, this.dd, this.df, a, b, c, d, e, f, g);
        this.an();
    }
    a8() {
        super.a8();
    }
    a9() {
        super.a9();
        this.c8.aj = this.de.aj;
        this.c9.aj = this.df.aj;
        this.c7.aj = this.dd.aj;
        let a = this.bk();
        this.c8._stroke = a;
        this.c8.ac = this.e.eu + 3;
        this.c9._stroke = a;
        this.c9.ac = this.e.eu + 3;
        this.c7._fill = a;
        this.c7._opacity = 1;
    }
    a3(a, b) {
        super.a3(a, b);
        if (a.d) {
            if (b) {
                a.s(this.c7);
                a.s(this.c8);
                a.s(this.c9);
            }
            else {
                a.s(this.dd);
                a.s(this.de);
                a.s(this.df);
            }
        }
    }
    ai(a) {
        super.ai(a);
        this.e.a2.exportPathData(a, this.de, "lowerShape", ["Lower", "Main"]);
        this.e.a2.exportPathData(a, this.df, "upperShape", ["Upper"]);
        this.e.a2.exportPathData(a, this.dd, "translucentShape", ["Translucent"]);
    }
    ac() {
        let a = new Color();
        a.colorString = "rgba(95,95,95,0.5)";
        this.e.k1 = a;
        this.e.er = 3;
        this.e.es = 1;
        this.e.et = 4;
        this.e.ds = false;
    }
}
LineSeriesView.$t = markType(LineSeriesView, 'LineSeriesView', AnchoredCategorySeriesView.$);
/*<BeginStatics Name="Infragistics.Controls.Charts.LineSeries" />*/
/*<EndStatics Name="Infragistics.Controls.Charts.LineSeries" />*/

==> igniteui-react-charts-16.6.4.tgz: package/ES2015/LineSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { HorizontalAnchoredCategorySeries } from "./HorizontalAnchoredCategorySeries";
import { IUnknownValuePlotting_$type } from "igniteui-react-core/ES2015/IUnknownValuePlotting";
import { CategoryLineRasterizer } from "./CategoryLineRasterizer";
import { UnknownValuePlotting_$type } from "igniteui-react-core/ES2015/UnknownValuePlotting";
import { DependencyProperty } from "igniteui-react-core/ES2015/DependencyProperty";
import { Type, typeCast, runOn, enumGetBox, markType } from "igniteui-react-core/ES2015/type";
import { Path } from "igniteui-react-core/ES2015/Path";
import { ScalerParams } from "./ScalerParams";
import { PropertyMetadata } from "igniteui-react-core/ES2015/PropertyMetadata";
import { AnchoredCategorySeriesView } from "./AnchoredCategorySeriesView";
import { ISortingAxis_$type } from "./ISortingAxis";
import { Color } from "igniteui-react-core/ES2015/Color";
export class LineSeries extends HorizontalAnchoredCategorySeries {
    constructor() {
        super();
        this.p8 = null;
        this.p8 = new CategoryLineRasterizer();
        this.ab = LineSeries.$;
        this.ps = 0;
    }
    bf() {
        return new LineSeriesView(this);
    }
    il(a) {
        super.il(a);
        this.p9 = a;
    }
    get_ck() {
        return true;
    }
    preferredCategoryMode(a) {
        return this.ps;
    }
    ho(a, b) {
        super.ho(a, b);
        let c = b;
        c.c7();
    }
    of(a, b) {
        super.of(a, b);
        let c = b.cn.d;
        let d = typeCast(LineSeriesView.$, b);
        let e = a.f;
        let f = this.getEffectiveViewport1(b);
        this.m5.x(this, this.nq(), this.pp, runOn(this, this.mr), this.ny(b), this.nz(b));
        let g = false;
        let h = this.m5.c;
        if (h != null) {
            g = true;
        }
        if (g) {
            let i = new ScalerParams(0, b.bs, b.br, this.pp.b8, f);
            this.ob(e, -1, this.valueColumn.count, this.pp, i, b.n);
        }
        let j = d.dd;
        let k = d.de;
        let l = d.dc;
        this.m5.ae(j, true, false, true, false);
        this.m5.ae(k, true, false, true, false);
        this.m5.ae(l, false, true, false, false);
        l._opacity = 0.75 * this.m5.i;
        if (b.cr(a)) {
            d.c8(e.count, e, true, this.unknownValuePlotting, this.on(e, e.count - 1, b.br, b.bs), c, this.eq);
            b.cu(a);
        }
    }
    ir(a, b, c, d) {
        super.ir(a, b, c, d);
        switch (b) {
            case LineSeries.$$p[0]:
                this.m2.m = this.unknownValuePlotting == 0;
                this.i4(false);
                this.ib();
                break;
        }
    }
    get useHighMarkerFidelity() {
        return this.nt;
    }
}
LineSeries.$t = markType(LineSeries, 'LineSeries', HorizontalAnchoredCategorySeries.$, [IUnknownValuePlotting_$type]);
Type.dep(DependencyProperty, PropertyMetadata, LineSeries, 'raisePropertyChanged', ['UnknownValuePlotting::qb', [UnknownValuePlotting_$type, enumGetBox(UnknownValuePlotting_$type, 1)]]);
export class LineSeriesView extends AnchoredCategorySeriesView {
    constructor(a) {
        super(a);
        this.c6 = null;
        this.dg = new Path();
        this.df = new Path();
        this.dh = new Path();
        this.db = new Path();
        this.da = new Path();
        this.c9 = new Path();
        this.c6 = a;
    }
    get dd() {
        return this.dg;
    }
    get de() {
        return this.dh;
    }
    get dc() {
        return this.df;
    }
    c7() {
        this.df.aj = null;
        this.dg.aj = null;
        this.dh.aj = null;
        this.an();
    }
    c8(a, b, c, d, e, f, g) {
        this.c6.p8.a = typeCast(ISortingAxis_$type, this.cp.fetchXAxis()) !== null ? true : false;
        this.c6.p8.m(this.dg, this.df, this.dh, a, b, c, d, e, f, g);
        this.an();
    }
    a8() {
        super.a8();
    }
    a9() {
        super.a9();
        this.da.aj = this.dg.aj;
        this.db.aj = this.dh.aj;
        this.c9.aj = this.df.aj;
        let a = this.bl();
        this.da._stroke = a;
        this.da.ac = this.e.eu + 3;
        this.db._stroke = a;
        this.db.ac = this.e.eu + 3;
        this.c9._fill = a;
        this.c9._opacity = 1;
    }
    a3(a, b) {
        super.a3(a, b);
        if (a.d) {
            if (b) {
                a.s(this.c9);
                a.s(this.da);
                a.s(this.db);
            }
            else {
                a.s(this.df);
                a.s(this.dg);
                a.s(this.dh);
            }
        }
    }
    ai(a) {
        super.ai(a);
        this.e.a2.exportPathData(a, this.dg, "lowerShape", ["Lower", "Main"]);
        this.e.a2.exportPathData(a, this.dh, "upperShape", ["Upper"]);
        this.e.a2.exportPathData(a, this.df, "translucentShape", ["Translucent"]);
    }
    ac() {
        let a = new Color();
        a.colorString = "rgba(95,95,95,0.5)";
        this.e.k1 = a;
        this.e.er = 3;
        this.e.es = 1;
        this.e.et = 4;
        this.e.ds = false;
    }
}
LineSeriesView.$t = markType(LineSeriesView, 'LineSeriesView', AnchoredCategorySeriesView.$);
